package com.link.core.basic.aop;

import com.alibaba.fastjson.JSONObject;
import com.link.base.kafkalogrecord.model.KafkaLogRecord;
import com.link.base.kafkalogrecord.service.KafkaLogRecordService;
import com.link.core.basic.annotations.KafkaLog;
import com.link.core.cllog.LCLogger;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Resource;
import org.apache.kafka.clients.consumer.Consumer;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.kafka.support.Acknowledgment;
import org.springframework.stereotype.Component;

@Component
@Aspect
public class KafkaLogAspect {
   @Resource
   private KafkaLogRecordService kafkaLogRecordService;
   private Object arg;

   @Pointcut("@annotation(com.link.core.basic.annotations.KafkaLog)")
   public void pointcut() {
   }

   @Around("pointcut()")
   public void around(ProceedingJoinPoint point) {
      List<KafkaLogRecord> kafkaLogRecord = new ArrayList();
      List<String> records = new ArrayList();
      Object[] args = point.getArgs();

      try {
         MethodSignature signature = (MethodSignature)point.getSignature();
         KafkaLog kafkaLog = (KafkaLog)signature.getMethod().getAnnotation(KafkaLog.class);
         Object[] var17 = args;
         int var8 = args.length;
         int var9 = 0;

         while(true) {
            if (var9 >= var8) {
               return;
            }

            Object arg = var17[var9];
            List kafkaLogRecord;
            if (arg instanceof String) {
               records.add(arg.toString());
               kafkaLogRecord = this.kafkaLogRecordService.insertStartLog(kafkaLog.moduleName(), kafkaLog.topicName(), records);
               point.proceed();
               this.kafkaLogRecordService.insertEndLog(kafkaLogRecord);
               break;
            }

            if (arg instanceof List) {
               Iterator var18 = ((List)arg).iterator();

               while(var18.hasNext()) {
                  ConsumerRecord consumerRecord = (ConsumerRecord)var18.next();
                  records.add(null == consumerRecord.value() ? "" : consumerRecord.value().toString());
               }

               kafkaLogRecord = this.kafkaLogRecordService.insertStartLog(kafkaLog.moduleName(), kafkaLog.topicName(), records);
               point.proceed();
               this.kafkaLogRecordService.insertEndLog(kafkaLogRecord);
               break;
            }

            if (arg instanceof ConsumerRecord) {
               ConsumerRecord consumerRecord = (ConsumerRecord)arg;
               records.add(null == consumerRecord.value() ? "" : consumerRecord.value().toString());
               kafkaLogRecord = this.kafkaLogRecordService.insertStartLog(kafkaLog.moduleName(), kafkaLog.topicName(), records);
               point.proceed();
               this.kafkaLogRecordService.insertEndLog(kafkaLogRecord);
               break;
            }

            if (!(arg instanceof Acknowledgment) && !(arg instanceof Consumer)) {
               records.add(JSONObject.toJSONString(arg));
               kafkaLogRecord = this.kafkaLogRecordService.insertStartLog(kafkaLog.moduleName(), kafkaLog.topicName(), records);
               point.proceed();
               this.kafkaLogRecordService.insertEndLog(kafkaLogRecord);
               break;
            }

            if (!(arg instanceof Acknowledgment) && !(arg instanceof Consumer)) {
               break;
            }

            ++var9;
         }

      } catch (Throwable var13) {
         Throwable e = var13;
         Iterator var6 = kafkaLogRecord.iterator();

         while(var6.hasNext()) {
            KafkaLogRecord kafkaLogRecord1 = (KafkaLogRecord)var6.next();
            kafkaLogRecord1.setErrorMsg(e.getMessage());
         }

         this.kafkaLogRecordService.insertErrorLog(kafkaLogRecord);
         LCLogger.error().withMessageKey("KafkaLog").withMessage("KafkaLog报错" + e.getMessage()).flush();
      }
   }
}
